==> forestry_1.12.1-5.5.5.192-sources.jar: forestry/greenhouse/network/packets/PacketGreenhouseData.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.greenhouse.network.packets;

import java.io.IOException;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.util.math.BlockPos;

import forestry.api.multiblock.IGreenhouseComponent;
import forestry.core.multiblock.MultiblockUtil;
import forestry.core.network.ForestryPacket;
import forestry.core.network.IForestryPacketClient;
import forestry.core.network.IForestryPacketHandlerClient;
import forestry.core.network.PacketBufferForestry;
import forestry.core.network.PacketIdClient;
import forestry.greenhouse.api.greenhouse.IGreenhouseProvider;
import forestry.greenhouse.multiblock.IGreenhouseControllerInternal;
import forestry.greenhouse.multiblock.blocks.storage.GreenhouseProvider;
import forestry.greenhouse.multiblock.blocks.storage.GreenhouseProviderClient;
import forestry.greenhouse.multiblock.blocks.storage.GreenhouseProviderServer;
import forestry.greenhouse.multiblock.blocks.world.GreenhouseBlockManager;

public class PacketGreenhouseData extends ForestryPacket implements IForestryPacketClient {

	BlockPos pos;
	GreenhouseProviderServer provider;

	public PacketGreenhouseData(BlockPos pos, GreenhouseProviderServer provider) {
		this.pos = pos;
		this.provider = provider;
	}

	@Override
	public PacketIdClient getPacketId() {
		return PacketIdClient.GREENHOUSE_DATA;
	}

	@Override
	protected void writeData(PacketBufferForestry data) throws IOException {
		data.func_179255_a(pos);
		provider.writeData(data);
	}

	public static class Handler implements IForestryPacketHandlerClient {

		public Handler() {
		}

		@Override
		public void onPacketData(PacketBufferForestry data, EntityPlayer player) throws IOException {
			BlockPos pos = data.func_179259_c();
			IGreenhouseControllerInternal controller = MultiblockUtil.getController(player.field_70170_p, pos, IGreenhouseComponent.class);
			if (controller == null) {
				return;
			}
			IGreenhouseProvider provider = controller.getProvider();
			if (provider instanceof GreenhouseProvider) {
				GreenhouseProviderClient providerClient = (GreenhouseProviderClient) provider;
				providerClient.readData(data);
			}
			GreenhouseBlockManager manager = GreenhouseBlockManager.getInstance();
			//provider.recreate();
			manager.markProviderDirty(player.field_70170_p, controller.getProvider().getCenterPos(), provider);
		}
	}
}

==> forestry_1.12.2-5.8.1.334-sources.jar: forestry/greenhouse/network/packets/PacketGreenhouseData.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.greenhouse.network.packets;

import java.io.IOException;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.util.math.BlockPos;

import forestry.api.multiblock.IGreenhouseComponent;
import forestry.core.multiblock.MultiblockUtil;
import forestry.core.network.ForestryPacket;
import forestry.core.network.IForestryPacketClient;
import forestry.core.network.IForestryPacketHandlerClient;
import forestry.core.network.PacketBufferForestry;
import forestry.core.network.PacketIdClient;
import forestry.greenhouse.api.greenhouse.IGreenhouseProvider;
import forestry.greenhouse.multiblock.IGreenhouseControllerInternal;
import forestry.greenhouse.multiblock.blocks.storage.GreenhouseProvider;
import forestry.greenhouse.multiblock.blocks.storage.GreenhouseProviderClient;
import forestry.greenhouse.multiblock.blocks.storage.GreenhouseProviderServer;
import forestry.greenhouse.multiblock.blocks.world.GreenhouseBlockManager;

public class PacketGreenhouseData extends ForestryPacket implements IForestryPacketClient {

	BlockPos pos;
	GreenhouseProviderServer provider;

	public PacketGreenhouseData(BlockPos pos, GreenhouseProviderServer provider) {
		this.pos = pos;
		this.provider = provider;
	}

	@Override
	public PacketIdClient getPacketId() {
		return PacketIdClient.GREENHOUSE_DATA;
	}

	@Override
	protected void writeData(PacketBufferForestry data) {
		data.func_179255_a(pos);
		provider.writeData(data);
	}

	public static class Handler implements IForestryPacketHandlerClient {

		public Handler() {
		}

		@Override
		public void onPacketData(PacketBufferForestry data, EntityPlayer player) throws IOException {
			BlockPos pos = data.func_179259_c();
			IGreenhouseControllerInternal controller = MultiblockUtil.getController(player.field_70170_p, pos, IGreenhouseComponent.class);
			if (controller == null) {
				return;
			}
			IGreenhouseProvider provider = controller.getProvider();
			if (provider instanceof GreenhouseProvider) {
				GreenhouseProviderClient providerClient = (GreenhouseProviderClient) provider;
				providerClient.readData(data);
			}
			GreenhouseBlockManager manager = GreenhouseBlockManager.getInstance();
			//provider.recreate();
			manager.markProviderDirty(player.field_70170_p, controller.getProvider().getCenterPos(), provider);
		}
	}
}
